@@ -2,10 +2,12 @@ from .aws import S3Location
 from .db import CachedAthenaQuery, CachedPep249Query, BaseCachedQuery, AthenaClient, SqlClient
 from .doggo import PandasDoggo, FileDoggo, CSVDoggo, DoggoFileSystem, DoggoLock, DoggoWait, DynamoDogLock
 from .log import log_to_stdout, PersistentFieldLogger
+from .tests import BaseTest
 
 __all__ = ['S3Location',
            'CachedAthenaQuery', 'CachedPep249Query', 'BaseCachedQuery',
            'PandasDoggo', 'FileDoggo', 'CSVDoggo', 'DoggoFileSystem',
            'DoggoLock', 'DoggoWait', 'log_to_stdout', 'PersistentFieldLogger',
-           'AthenaClient', 'SqlClient'
+           'AthenaClient', 'SqlClient',
+           'BaseTest'
            ]
\ No newline at end of file
